@@ -1,3 +1,20 @@
+/** 
+ *  This file is a part of Esperanza, an XMMS2 Client.
+ *
+ *  Copyright (C) 2005-2006 XMMS2 Team
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License
+ *  as published by the Free Software Foundation; either version 2
+ *  of the License, or (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ */
+
+
 #ifndef __PLAYLIST_VIEW_H__
 #define __PLAYLIST_VIEW_H__
 
@@ -30,6 +47,10 @@ class PlaylistView : public QTreeView
 		void keyPressEvent (QKeyEvent *);
 		void mousePressEvent (QMouseEvent *);
 
+		PlaylistModel *model () const {
+			return m_model;
+		};
+
 		void set_removed (bool b) {
 			m_removed = b;
 		};
@@ -41,6 +62,7 @@ class PlaylistView : public QTreeView
 		void changed_settings ();
 		void rows_inserted ();
 		void head_size (int, int, int);
+		void moved (const QModelIndex &, const QModelIndex &);
 
 	signals:
 		void selectedID (uint32_t);
